#ifndef LOADFLOW_H
#define LOADFLOW_H

struct bus_data
{
   int    Num;
   char   Name[13];
   int    Area;
   int    Loss_Zone;
   int    Type;
   double Final_Voltage;
   double Final_Degree;
   double Load_Re;
   double Load_Im;
   double Generation_Re;
   double Generation_Im;
   double Base_KV;
   double Desired_Voltage;
   double Limits_Max;  /* MVAR  or V */
   double Limits_Min;  /* MVAR  or V */
   double Impedience_Re;
   double Impedience_Im;
};

typedef struct bus_data bus_data;

struct branch_data
{
   int    Tab_bus;
   int    Impedience_bus;
   int    Area;
   int    Zone;
   int    Circuit;
   int    Type;
   double Impedience_Re;
   double Impedience_Im;
   double Charging;
   double Line_Rating[3];
   int    Control_bus;
   int    Side;
   double Transformer_final_ratio;
   double Transformer_final_angle;
   double Tap_Phase_shift_Max;
   double Tap_Phase_shift_Min;
   double Step_size;
   double Voltage_Limit_Max;
   double Voltage_Limit_Min;
};

typedef struct branch_data branch_data;

struct loss_zone
{
   int Zone;
   char Name[13];
};

typedef struct loss_zone loss_zone;

struct interchange_data
{
   int    Area;
   int    Bus_num;
   int    Bus_Name[13];
   double Scheduled_Export;
   double Tolerance;
   char   Area_Code[7];
   int    Area_Name[31];
};

typedef struct interchange_data interchange_data;

struct tie_line
{
   int    Meter_Bus_Area;
   int    Meter_Bus_num;
   int    Non_Meter_Bus_Area;
   int    Non_Meter_Bus_num;
   int    Circuit;
};

typedef struct tie_line tie_line;


struct loadflow
{
   int               Num_bus;
   bus_data         *Bus_Data;
   int               Num_branch;
   branch_data      *Branch_Data;
   int               Num_loss_zone;
   loss_zone        *Loss_Zone;
   int               Num_interchange;
   interchange_data *Interchange_Data;
   int               Num_tie_line;
   tie_line         *Tie_Line;
};

typedef struct loadflow loadflow;

#define LINE_LENGTH 133

#define UNKNOWN          0
#define BUS_DATA         1
#define BRANCH_DATA      2
#define LOSS_ZONE        3
#define INTERCHANGE_DATA 4
#define TIE_LINE         5
#define END_OF_DATA      6

#endif

#include <stdio.h>
#include <errno.h>
